@@ -20,6 +20,7 @@ class Chromium(ChromiumBasedBrowser):
     """
 
     name = "Chromium"
+    aliases = ("chromiumhtm", "chromium-browser", "chromiumhtml")
 
     linux_path = ".config/chromium"
     windows_path = "AppData/Local/chromium/User Data"
@@ -40,10 +41,11 @@ class Chrome(ChromiumBasedBrowser):
     """
 
     name = "Chrome"
+    aliases = ("chromehtml", "google-chrome", "chromehtm")
 
+    linux_path = ".config/google-chrome"
     windows_path = "AppData/Local/Google/Chrome/User Data"
     mac_path = "Library/Application Support/Google/Chrome/"
-    linux_path = ".config/google-chrome"
 
     profile_support = True
 
@@ -61,9 +63,10 @@ class Firefox(Browser):
     """
 
     name = "Firefox"
+    aliases = ("firefoxurl",)
 
-    windows_path = "AppData/Roaming/Mozilla/Firefox/Profiles"
     linux_path = ".mozilla/firefox"
+    windows_path = "AppData/Roaming/Mozilla/Firefox/Profiles"
     mac_path = "Library/Application Support/Firefox/Profiles/"
 
     profile_support = True
@@ -177,7 +180,9 @@ class Edge(ChromiumBasedBrowser):
     """
 
     name = "Edge"
+    aliases = ("msedgehtm", "msedge", "microsoft-edge", "microsoft-edge-dev")
 
+    linux_path = ".config/microsoft-edge-dev"
     windows_path = "AppData/Local/Microsoft/Edge/User Data"
     mac_path = "Library/Application Support/Microsoft Edge"
 
@@ -195,6 +200,7 @@ class Opera(ChromiumBasedBrowser):
     """
 
     name = "Opera"
+    aliases = ("operastable", "opera-stable")
 
     linux_path = ".config/opera"
     windows_path = "AppData/Roaming/Opera Software/Opera Stable"
@@ -214,6 +220,7 @@ class OperaGX(ChromiumBasedBrowser):
     """
 
     name = "OperaGX"
+    aliases = ("operagxstable", "operagx-stable")
 
     windows_path = "AppData/Roaming/Opera Software/Opera GX Stable"
 
@@ -233,9 +240,31 @@ class Brave(ChromiumBasedBrowser):
     """
 
     name = "Brave"
+    aliases = ("bravehtml",)
 
     linux_path = ".config/BraveSoftware/Brave-Browser"
     mac_path = "Library/Application Support/BraveSoftware/Brave-Browser"
     windows_path = "AppData/Local/BraveSoftware/Brave-Browser/User Data"
 
     profile_support = True
+
+
+class Vivaldi(ChromiumBasedBrowser):
+    """Vivaldi Browser
+
+    Supported platforms (TODO: Add Mac OS support)
+
+    * Linux
+    * Windows
+
+    Profile support: Yes
+    """
+
+    name = "Vivaldi"
+    aliases = ("vivaldi-stable", "vivaldistable")
+
+    linux_path = ".config/vivaldi"
+    mac_path = "Library/Application Support/Vivaldi"
+    windows_path = "AppData/Local/Vivaldi/User Data"
+
+    profile_support = True
