@@ -49,6 +49,7 @@ class Browser(abc.ABC):
     * :py:class:`profile_support`
     * :py:class:`profile_dir_prefixes`
     * :py:class:`_local_tz`
+    * :py:class:`aliases`: A tuple containing other names for the browser in lowercase
 
     :param plat: the current platform. A value of :py:class:`None` means the platform
        will be inferred from the system.
@@ -57,6 +58,7 @@ class Browser(abc.ABC):
 
     >>> class CustomBrowser(Browser):
     ...     name = 'custom browser'
+    ...     aliases = ('custom-browser', 'customhtm')
     ...     history_file = 'history_file'
     ...     history_SQL = \"\"\"
     ...         SELECT
@@ -93,6 +95,12 @@ class Browser(abc.ABC):
     history_dir: Path
     """History directory."""
 
+    aliases: tuple = ()
+    """Gets possible names (lower-cased) used to refer to the browser type.
+    Useful for making the browser detectable as a default browser which may be
+    named in various forms on different platforms. Do not include :py:class:`name`
+    in this list"""
+
     @property
     @abc.abstractmethod
     def name(self) -> str:
@@ -120,15 +128,17 @@ class Browser(abc.ABC):
             plat = utils.get_platform()
         homedir = Path.home()
 
-        error_string = self.name + " browser is not supported on {}"
+        error_string = (
+            f"{self.name} browser is not supported on {utils.get_platform_name(plat)}"
+        )
         if plat == utils.Platform.WINDOWS:
-            assert self.windows_path is not None, error_string.format("windows")
+            assert self.windows_path is not None, error_string
             self.history_dir = homedir / self.windows_path
         elif plat == utils.Platform.MAC:
-            assert self.mac_path is not None, error_string.format("Mac OS")
+            assert self.mac_path is not None, error_string
             self.history_dir = homedir / self.mac_path
         elif plat == utils.Platform.LINUX:
-            assert self.linux_path is not None, error_string.format("Linux")
+            assert self.linux_path is not None, error_string
             self.history_dir = homedir / self.linux_path
         else:
             raise NotImplementedError()
@@ -185,6 +195,21 @@ class Browser(abc.ABC):
             return None
         return self.history_dir / profile_dir / self.history_file
 
+    def bookmarks_path_profile(self, profile_dir: Path) -> typing.Optional[Path]:
+        """Returns path of the bookmark file for the given ``profile_dir``
+
+        The ``profile_dir`` should be one of the outputs from
+        :py:meth:`profiles`
+
+        :param profile_dir: Profile directory (should be a single name,
+            relative to ``history_dir``)
+        :type profile_dir: :py:class:`pathlib.Path`
+        :return: path to bookmark file of the profile
+        """
+        if self.bookmarks_file is None:
+            return None
+        return self.history_dir / profile_dir / self.bookmarks_file
+
     def paths(self, profile_file):
         """Returns a list of file paths, for all profiles.
 
@@ -242,7 +267,9 @@ class Browser(abc.ABC):
         with tempfile.TemporaryDirectory() as tmpdirname:
             for history_path in history_paths:
                 copied_history_path = shutil.copy2(history_path.absolute(), tmpdirname)
-                conn = sqlite3.connect(f"file:{copied_history_path}?mode=ro", uri=True)
+                conn = sqlite3.connect(
+                    f"file:{copied_history_path}?mode=ro&immutable=1&nolock=1", uri=True
+                )
                 cursor = conn.cursor()
                 cursor.execute(self.history_SQL)
                 date_histories = [
@@ -305,6 +332,20 @@ class Browser(abc.ABC):
                 output_object.bookmarks.sort(reverse=desc)
         return output_object
 
+    @classmethod
+    def is_supported(cls):
+        """Checks whether the browser is supported on current platform
+
+        :return: True if browser is supported on current platform else False
+        :rtype: boolean
+        """
+        support_check = {
+            utils.Platform.LINUX: cls.linux_path,
+            utils.Platform.WINDOWS: cls.windows_path,
+            utils.Platform.MAC: cls.mac_path,
+        }
+        return support_check.get(utils.get_platform()) is not None
+
 
 class Outputs:
     """
@@ -570,12 +611,16 @@ class ChromiumBasedBrowser(Browser, abc.ABC):
                 if node == "children":
                     for child in bookmarks_json[node]:
                         if child["type"] == "url":
-                            d_t = datetime.datetime(1601, 1, 1) + datetime.timedelta(
+                            d_t = datetime.datetime(
+                                1601, 1, 1, tzinfo=datetime.timezone.utc
+                            ) + datetime.timedelta(
                                 microseconds=int(child["date_added"])
                             )
                             bookmarks_list.append(
                                 (
-                                    d_t.replace(microsecond=0, tzinfo=self._local_tz),
+                                    d_t.replace(microsecond=0).astimezone(
+                                        self._local_tz
+                                    ),
                                     child["url"],
                                     child["name"],
                                     folder,
